@@ -47,6 +47,9 @@ def qq_download_by_vid(vid, title, output_dir='.', merge=True, info_only=False):
             else:
                 log.w(key_json['msg'])
             break
+        if key_json.get('filename') is None:
+            log.w(key_json['msg'])
+            break
 
         part_urls.append(url)
         _, ext, size = url_info(url)
@@ -121,18 +124,6 @@ def qq_download(url, output_dir='.', merge=True, info_only=False, **kwargs):
             qq_download_by_vid(vid, vid, output_dir, merge, info_only)
         return
 
-    #do redirect
-    if 'v.qq.com/page' in url:
-        # for URLs like this:
-        # http://v.qq.com/page/k/9/7/k0194pwgw97.html
-        new_url = url_locations([url])[0]
-        if url == new_url:
-            #redirect in js?
-            content = get_content(url)
-            url = match1(content,r'window\.location\.href="(.*?)"')
-        else:
-            url = new_url
-
     if 'kuaibao.qq.com' in url or re.match(r'http://daxue.qq.com/content/content/id/\d+', url):
         content = get_content(url)
         vid = match1(content, r'vid\s*=\s*"\s*([^"]+)"')
@@ -149,6 +140,9 @@ def qq_download(url, output_dir='.', merge=True, info_only=False, **kwargs):
         vid = ""
         if rurl:
             vid = rurl.split('/')[-1].split('.')[0]
+            # https://v.qq.com/x/page/d0552xbadkl.html https://y.qq.com/n/yqq/mv/v/g00268vlkzy.html
+            if vid == "undefined" or vid == "index":
+                vid = ""
         vid = vid if vid else url.split('/')[-1].split('.')[0] #https://v.qq.com/x/cover/ps6mnfqyrfo7es3/q0181hpdvo5.html?
         vid = vid if vid else match1(content, r'vid"*\s*:\s*"\s*([^"]+)"') #general fallback
         if not vid:
