@@ -31,6 +31,19 @@ def universal_download(url, output_dir='.', merge=True, info_only=False, **kwarg
         if page_title:
             page_title = unescape_html(page_title)
 
+        meta_videos = re.findall(r'<meta property="og:video:url" content="([^"]*)"', page)
+        if meta_videos:
+            for meta_video in meta_videos:
+                meta_video_url = unescape_html(meta_video)
+                type_, ext, size = url_info(meta_video_url)
+                print_info(site_info, page_title, type_, size)
+                if not info_only:
+                    download_urls([meta_video_url], page_title,
+                                  ext, size,
+                                  output_dir=output_dir, merge=merge,
+                                  faker=True)
+            return
+
         hls_urls = re.findall(r'(https?://[^;"\'\\]+' + '\.m3u8?' +
                               r'[^;"\'\\]*)', page)
         if hls_urls:
@@ -67,6 +80,14 @@ def universal_download(url, output_dir='.', merge=True, info_only=False, **kwarg
         urls += re.findall(r'href="(https?://[^"]+\.png)"', page, re.I)
         urls += re.findall(r'href="(https?://[^"]+\.gif)"', page, re.I)
 
+        # relative path
+        rel_urls = []
+        rel_urls += re.findall(r'href="(\.[^"]+\.jpe?g)"', page, re.I)
+        rel_urls += re.findall(r'href="(\.[^"]+\.png)"', page, re.I)
+        rel_urls += re.findall(r'href="(\.[^"]+\.gif)"', page, re.I)
+        for rel_url in rel_urls:
+            urls += [ r1(r'(.*/)', url) + rel_url ]
+
         # MPEG-DASH MPD
         mpd_urls = re.findall(r'src="(https?://[^"]+\.mpd)"', page)
         for mpd_url in mpd_urls:
@@ -104,10 +125,9 @@ def universal_download(url, output_dir='.', merge=True, info_only=False, **kwarg
 
     else:
         # direct download
-        filename = parse.unquote(url.split('/')[-1])
-        title = '.'.join(filename.split('.')[:-1])
-        ext = filename.split('.')[-1]
-        _, _, size = url_info(url, faker=True)
+        filename = parse.unquote(url.split('/')[-1]) or parse.unquote(url.split('/')[-2])
+        title = '.'.join(filename.split('.')[:-1]) or filename
+        _, ext, size = url_info(url, faker=True)
         print_info(site_info, title, ext, size)
         if not info_only:
             download_urls([url], title, ext, size,
